==> piwigo-11.5.0.zip: piwigo/language/es_MX/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+
$lang['user login given by your host provider'] = 'nombre de usuario suministrado por tu proveedor de hospedaje';
$lang['user password given by your host provider'] = 'contraseña suministrada por tu proveedor de hospedaje';
$lang['verification'] = 'verificación';
$lang['webmaster login can\'t contain characters \' or "'] = 'el nombre de usuario del administrador del sitio no puede contener caracteres \' o "';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = '¿Necesitas ayuda? Plantea tu pregunta en el <a href="%s">tablero de mensajes Piwigo</a>.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Ten en cuenta que puedes modificar tu configuración por ti mismo y después reiniciar Piwigo.';
$lang['PHP 5 is required'] = 'Se requiere PHP 5.2';
$lang['Password ']['confirm'] = 'Contraseña [confirmación]';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo puede intentar de cambiar tu configuración a PHP 5.2 creando o modificando el archivo .htaccess';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo no pudo configurar PHP 5.2';
$lang['Sorry!'] = '¡Disculpa!';
$lang['Start Install'] = 'Comenzar instalación';
$lang['Try to configure PHP 5'] = 'Intenta configurar PHP 5.2';
$lang['User'] = 'Usuario';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Los visitantes podrán utilizar este correo electrónico para contactar al administrador del sitio';
$lang['Welcome to my photo gallery'] = 'Bienvenido a mi galería de fotos';
$lang['Welcome to your new installation of Piwigo!'] = '¡Bienvenido a tu nieva instalación de Piwigo!';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Puedes descargar el archivo de configuración y cargarlo al directorio local/config de tu instalación.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Deberías consultar al centro de soporte de tu proveedor de hospedaje y ver la manera de cambiar a PHP 5.2 por ti mismo.';
$lang['also given by your host provider'] = 'también suministrado por tu proveedor de hospedaje';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'las tablas de la base de datos lo contendrán como prefijo (te permite administrar mejor tus tablas)';
$lang['enter a login for webmaster'] = 'por favor ingresa el nombre de usuario de administrador del sitio';
$lang['localhost or other, supplied by your host provider'] = 'localhost u otro, suministrado por tu proveedor de hospedaje';
$lang['please enter your password again'] = 'por favor ingresa nuevamente tu contraseña';
$lang['Admin configuration'] = 'Configuración de administración';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Una solución alterna es copiar el texto en el cuadro de arriba y pegarlo en el archivo "local/config/database.inc.php" (Precaución: databa.inc.php solo debe contener lo que se encuentra en el área de texto, sin retornos de línea o espacios)';
$lang['Basic configuration'] = 'Configuración básica';
$lang['Can\'t connect to server'] = 'No se puede conectar al servidor';
$lang['Congratulations, Piwigo installation is completed'] = 'Felicidades, la instalación de Piwigo se ha completado';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'La conexión al servidor fue exitosa, pero no fue posible establecer conexión con la base de datos.';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'La creación del archivo de configuración local/config/database.inc.php falló.';
$lang['Database configuration'] = 'Configuración de base de datos';
$lang['Database name'] = 'Nombre de base de datos';
$lang['Database table prefix'] = 'Prefijo de tablas de base de datos';
$lang['Default gallery language'] = 'Idioma por defecto de la galería';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'No dudes en consultar nuestros foros para cualquier ayuda necesaria: %s';
$lang['Download the config file'] = 'Descargar el archivo de configuración';
$lang['Hope to see you back soon.'] = 'Deseamos verte pronto de regreso.';
$lang['Host'] = 'Servidor';
$lang['Installation'] = 'Instalación';
$lang['It appears your webhost is currently running PHP %s.'] = 'Parece que tu servidor web corre actualmente PHP %s.';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Se mostrará a los visitantes. Es necesario para la administración del sitio web';
$lang['Just another Piwigo gallery'] = 'Otra galería Piwigo';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Mantenlo confidencial, te permite acceder al panel de administración';

==> piwigo-16.0.0.zip: piwigo/language/es_MX/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+
$lang['user login given by your host provider'] = 'nombre de usuario suministrado por tu proveedor de hospedaje';
$lang['user password given by your host provider'] = 'contraseña suministrada por tu proveedor de hospedaje';
$lang['verification'] = 'verificación';
$lang['webmaster login can\'t contain characters \' or "'] = 'el nombre de usuario del administrador del sitio no puede contener caracteres \' o "';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = '¿Necesitas ayuda? Plantea tu pregunta en el <a href="%s">tablero de mensajes Piwigo</a>.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Ten en cuenta que puedes modificar tu configuración por ti mismo y después reiniciar Piwigo.';
$lang['PHP 5 is required'] = 'Se requiere PHP 5.2';
$lang['Password ']['confirm'] = 'Contraseña [confirmación]';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo puede intentar de cambiar tu configuración a PHP 5.2 creando o modificando el archivo .htaccess';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo no pudo configurar PHP 5.2';
$lang['Sorry!'] = '¡Disculpa!';
$lang['Start Install'] = 'Comenzar instalación';
$lang['Try to configure PHP 5'] = 'Intenta configurar PHP 5.2';
$lang['User'] = 'Usuario';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Los visitantes podrán utilizar este correo electrónico para contactar al administrador del sitio';
$lang['Welcome to my photo gallery'] = 'Bienvenido a mi galería de fotos';
$lang['Welcome to your new installation of Piwigo!'] = '¡Bienvenido a tu nieva instalación de Piwigo!';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Puedes descargar el archivo de configuración y cargarlo al directorio local/config de tu instalación.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Deberías consultar al centro de soporte de tu proveedor de hospedaje y ver la manera de cambiar a PHP 5.2 por ti mismo.';
$lang['also given by your host provider'] = 'también suministrado por tu proveedor de hospedaje';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'las tablas de la base de datos lo contendrán como prefijo (te permite administrar mejor tus tablas)';
$lang['enter a login for webmaster'] = 'por favor ingresa el nombre de usuario de administrador del sitio';
$lang['localhost or other, supplied by your host provider'] = 'localhost u otro, suministrado por tu proveedor de hospedaje';
$lang['please enter your password again'] = 'por favor ingresa nuevamente tu contraseña';
$lang['Admin configuration'] = 'Configuración de administración';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Una solución alterna es copiar el texto en el cuadro de arriba y pegarlo en el archivo "local/config/database.inc.php" (Precaución: databa.inc.php solo debe contener lo que se encuentra en el área de texto, sin retornos de línea o espacios)';
$lang['Basic configuration'] = 'Configuración básica';
$lang['Can\'t connect to server'] = 'No se puede conectar al servidor';
$lang['Congratulations, Piwigo installation is completed'] = 'Felicidades, la instalación de Piwigo se ha completado';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'La conexión al servidor fue exitosa, pero no fue posible establecer conexión con la base de datos.';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'La creación del archivo de configuración local/config/database.inc.php falló.';
$lang['Database configuration'] = 'Configuración de base de datos';
$lang['Database name'] = 'Nombre de base de datos';
$lang['Database table prefix'] = 'Prefijo de tablas de base de datos';
$lang['Default gallery language'] = 'Idioma por defecto de la galería';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'No dudes en consultar nuestros foros para cualquier ayuda necesaria: %s';
$lang['Download the config file'] = 'Descargar el archivo de configuración';
$lang['Hope to see you back soon.'] = 'Deseamos verte pronto de regreso.';
$lang['Host'] = 'Servidor';
$lang['Installation'] = 'Instalación';
$lang['It appears your webhost is currently running PHP %s.'] = 'Parece que tu servidor web corre actualmente PHP %s.';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Se mostrará a los visitantes. Es necesario para la administración del sitio web';
$lang['Just another Piwigo gallery'] = 'Otra galería Piwigo';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Mantenlo confidencial, te permite acceder al panel de administración';
$lang['PHP version %s required (you are running on PHP %s)'] = 'Se requiere la versión de PHP %s (usted está ejecutando PHP %s)';
